'use strict';

var fetchres = require('fetchres');
var catchNetworkErrors = require('./utils/catch-network-errors');
var logger = require('ft-next-logger');

module.exports = function(opts) {
	var uuid = opts.uuid;
	var useElasticSearch = opts.useElasticSearch;

	if (useElasticSearch && !process.env.ELASTIC_SEARCH_HOST) {
		throw new Error('Cannot use elastic search without an ELASTIC_SEARCH_HOST');
	}

	var url = useElasticSearch
		? 'https://' + process.env.ELASTIC_SEARCH_HOST + '/v1_api_v2/item/' + uuid
		: 'http://api.ft.com/content/items/v1/' + uuid + '?feature.blogposts=on';

	return fetch(url, {
			timeout: 3000,
			headers: {
				'X-Api-Key': process.env.apikey
			}
		})
			.catch(catchNetworkErrors)
			.then(function(response) {
				if (!response.ok) {
					logger.warn('Failed getting CAPIv1 content', {
						uuid: uuid,
						status: response.status
					});
				}
				return response;
			})
			.then(fetchres.json)
			.then(function(data) {
				return useElasticSearch ? data._source : data;
			});
};
